@@ -1,5 +1,3 @@
-# -*- python -*-
-# -*- coding: utf-8 -*-
 #
 #  This file is part of the fitter software
 #
@@ -21,7 +19,6 @@ import os
 import glob
 import json
 import sys
-import colorlog
 import textwrap
 import subprocess
 import click
@@ -44,18 +41,14 @@ def main():  # pragma: no cover
 @main.command()
 @click.argument("filename", type=click.STRING)
 @click.option("--column-number", type=click.INT, default=1)
-@click.option(
-    "--delimiter", type=click.STRING, default=",", help="look at the first column"
-)
+@click.option("--delimiter", type=click.STRING, default=",", help="look at the first column")
 @click.option(
     "--distributions",
     type=click.STRING,
     default="gamma,beta",
     help="llist of distribution",
 )
-@click.option(
-    "--tag", type=click.STRING, default="fitter", help="tag to name output files"
-)
+@click.option("--tag", type=click.STRING, default="fitter", help="tag to name output files")
 @click.option("--progress/--no-progress", default=True)
 @click.option("--verbose/--no-verbose", default=True)
 def fitdist(**kwargs):
@@ -96,6 +89,12 @@ def fitdist(**kwargs):
     with open("{}.log".format(tag), "w") as fout:
         fout.write(msg)
 
+@main.command()
+def show_distributions(**kwargs):
+    from fitter import get_distributions
+    print("\n".join(get_distributions()))
+
+
 
 if __name__ == "__main__":  # pragma: no cover
     main()
